==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/MARKOVTRANSITIONZONEID_Type.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MARKOVTRANSITIONZONEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MARKOVTRANSITIONZONEID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DECAYCURVEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MARKOVTRANSITIONZONENUMBER"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MARKOVTRANSITIONZONEID_Type", propOrder = {
    "decaycurveid",
    "markovtransitionzonenumber"
})
public class MARKOVTRANSITIONZONEID_Type {

    @XmlElement(name = "DECAYCURVEID", required = true)
    protected STANDARDENTITYID_Type decaycurveid;
    @XmlElement(name = "MARKOVTRANSITIONZONENUMBER", required = true)
    protected BigInteger markovtransitionzonenumber;

    /**
     * Gets the value of the decaycurveid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getDECAYCURVEID() {
        return decaycurveid;
    }

    /**
     * Sets the value of the decaycurveid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setDECAYCURVEID(STANDARDENTITYID_Type value) {
        this.decaycurveid = value;
    }

    /**
     * Gets the value of the markovtransitionzonenumber property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMARKOVTRANSITIONZONENUMBER() {
        return markovtransitionzonenumber;
    }

    /**
     * Sets the value of the markovtransitionzonenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMARKOVTRANSITIONZONENUMBER(BigInteger value) {
        this.markovtransitionzonenumber = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/MARKOVTRANSITIONZONEID_Type.java <==

package net.datastream.schemas.mp_fields;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MARKOVTRANSITIONZONEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MARKOVTRANSITIONZONEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DECAYCURVEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MARKOVTRANSITIONZONENUMBER"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MARKOVTRANSITIONZONEID_Type", propOrder = {
    "decaycurveid",
    "markovtransitionzonenumber"
})
public class MARKOVTRANSITIONZONEID_Type {

    @XmlElement(name = "DECAYCURVEID", required = true)
    protected STANDARDENTITYID_Type decaycurveid;
    @XmlElement(name = "MARKOVTRANSITIONZONENUMBER", required = true)
    protected BigInteger markovtransitionzonenumber;

    /**
     * Gets the value of the decaycurveid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getDECAYCURVEID() {
        return decaycurveid;
    }

    /**
     * Sets the value of the decaycurveid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setDECAYCURVEID(STANDARDENTITYID_Type value) {
        this.decaycurveid = value;
    }

    /**
     * Gets the value of the markovtransitionzonenumber property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMARKOVTRANSITIONZONENUMBER() {
        return markovtransitionzonenumber;
    }

    /**
     * Sets the value of the markovtransitionzonenumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMARKOVTRANSITIONZONENUMBER(BigInteger value) {
        this.markovtransitionzonenumber = value;
    }

}
